#
# spec file for package java-3d
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Asterios Dramis <asterios.dramis@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           java-3d
Version:        1.5.2
Release:        lp151.7.1
Summary:        Java 3D API
License:        GPL-2.0-with-classpath-exception AND BSD-3-Clause
Group:          Development/Libraries/Java
URL:            http://java3d.java.net/
# mkdir java3d-1.5.2
# cd java3d-1.5.2
# svn checkout https://svn.java.net/svn/vecmath~svn/tags/rel-1_5_2-fcs vecmath
# svn checkout https://svn.java.net/svn/j3d-core-utils~svn/tags/rel-1_5_2-fcs j3d-core-utils
# svn checkout https://svn.java.net/svn/j3d-core~svn/tags/rel-1_5_2-fcs j3d-core
# find vecmath/ -name .svn -type d | xargs rm -rf
# find j3d-core-utils/ -name .svn -type d | xargs rm -rf
# find j3d-core/ -name .svn -type d | xargs rm -rf
# cd ..
# tar jcf java3d-1.5.2.tar.bz2 java3d-1.5.2/
Source0:        java3d-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM java-7_fix.patch asterios.dramis@gmail.com -- Fix compilation with java-7
Patch0:         java-7_fix.patch
# PATCH-FIX-UPSTREAM Fix compilation with newer glx.h
Patch1:         java-3d-glxext.patch
Patch2:         java3d-1.5.2-sourcetarget.patch
Patch3:         java3d-1.5.2-native.patch
Patch4:         java-3d-nojavah.patch
Patch5:         java3d-1.5.2-appletaudioclip.patch
BuildRequires:  ant >= 1.9.8
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-tools
Requires:       java
Requires:       javapackages-tools
%if 0%{?suse_version} > 1210
BuildRequires:  Mesa-libGL-devel
BuildRequires:  libX11-devel
BuildRequires:  libXt-devel
%else
BuildRequires:  Mesa-devel
BuildRequires:  xorg-x11-devel
%endif

%description
The Java 3D API provides a set of object-oriented interfaces that support a
simple, high-level programming model you can use to build, render, and control
the behavior of 3D objects and visual environments. With the Java 3D API, you
can incorporate high quality, scalable, platform-independent 3D graphics into
applications and vecmath applets based on Java technology.

%prep
%setup -q -n java3d-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 11}%{!?pkg_vcmp:0}
%patch5 -p1
%endif

# Remove all third party jars
find . -iname '*.jar' | xargs rm -rf

# Remove bundled glext.h / openGL stuff
rm j3d-core/src/native/ogl/glext.h

# rm -rf j3d-core-utils/src/classes/share/com/sun/j3d/utils/applet

%build
pushd vecmath
ant \
    -Dcflags_extra.native="%{optflags}" \
    -Dant.build.javac.source=1.6 -Dant.build.javac.target=1.6 \
    jar-opt
popd

pushd j3d-core
ant \
    -Dcflags_extra.native="%{optflags}" \
    -Dant.build.javac.source=1.6 -Dant.build.javac.target=1.6 \
    compile-opt
ant \
    -Dcflags_extra.native="%{optflags}" \
    -Dant.build.javac.source=1.6 -Dant.build.javac.target=1.6 \
    jar-opt
popd

%install
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_javadir}/%{name}
mkdir -p %{buildroot}%{_javadocdir}/%{name}-%{version}

# library
install -pm 0755 j3d-core/build/linux-*/opt/lib/*/libj3dcore-ogl.so %{buildroot}%{_libdir}

# jars
install -pm 0644 j3d-core/build/linux-*/opt/lib/ext/j3dcore.jar %{buildroot}%{_javadir}/%{name}/j3dcore-%{version}.jar
install -pm 0644 j3d-core/build/linux-*/opt/lib/ext/j3dutils.jar %{buildroot}%{_javadir}/%{name}/j3dutils-%{version}.jar
install -pm 0644 vecmath/build/opt/lib/ext/vecmath.jar %{buildroot}%{_javadir}/%{name}/vecmath-%{version}.jar

# Make name of jars version agnostics
(cd %{buildroot}%{_javadir}/%{name} && for jar in *-%{version}*; do ln -sf ${jar} ${jar/-%{version}/}; done)

# Manually install doc files
mkdir -p %{buildroot}%{_docdir}/java3d/j3d-core
mkdir -p %{buildroot}%{_docdir}/java3d/j3d-core-utils
mkdir -p %{buildroot}%{_docdir}/java3d/vecmath
cd j3d-core
cp -a COPYRIGHT.txt LICENSE* README-FIRST.txt THIRDPARTY-LICENSE-*.txt docs/ release-info/fcs-1_5_2/ %{buildroot}%{_docdir}/java3d/j3d-core/
cd ../j3d-core-utils
cp -a COPYRIGHT.txt LICENSE.txt README-FIRST.txt THIRDPARTY-LICENSE-*.txt %{buildroot}%{_docdir}/java3d/j3d-core-utils/
cd ../vecmath
cp -a COPYRIGHT.txt LICENSE* README-FIRST.txt docs/ %{buildroot}%{_docdir}/java3d/vecmath/
cd ..

%fdupes -s %{buildroot}

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc %{_docdir}/java3d
%{_libdir}/libj3dcore-ogl.so
%{_javadir}/%{name}/

%changelog
* Mon Dec 17 2018 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * java-3d-glxext.patch
    + Guard typedefs by a macro so that we don't get conflicting
    typedefs
* Thu Sep 20 2018 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * java3d-1.5.2-appletaudioclip.patch
    + Applied on builds with jdk11 and further to fix builds
    + Use JavaSoundAudioClip instead of the removed AppletAudioClip
* Wed Jan 10 2018 fstrba@suse.com
- Added patch:
  * java-3d-nojavah.patch
  - Fix build with jdk10 that does not have javah tool any more
- Require jdk >= 1.8 for build, since jdk 1.8 understands the
  javac's "-h" option
* Tue Jan  2 2018 fstrba@suse.com
- Force build with jdk < 10 in order to be able to use javah tool
* Mon Sep 18 2017 fstrba@suse.com
- Added patches:
  * java3d-1.5.2-native.patch
    + Some hacks to build with the jdk9 file layout
  * java3d-1.5.2-sourcetarget.patch
    + Don't hardcode source and target in the build.xml files
- Build with java source and target 1.6 in order to allow building
  with jdk9
* Wed May  6 2015 tchvatal@suse.com
- Add patch to build correctly with new glx.h:
  * java-3d-glxext.patch
* Wed May  6 2015 tchvatal@suse.com
- Add bsd3c to licenses as core-utils and examples are under it
* Wed May  6 2015 tchvatal@suse.com
- Rename files to java-3d.{changes,spec}
- Sort out few dependencies and requirements
* Thu Jul  5 2012 asterios.dramis@gmail.com
- Added a patch (java-7_fix.patch) to fix compilation with java-7 in
  openSUSE > 12.1 (patch based on one from Debian).
* Fri Apr  6 2012 asterios.dramis@gmail.com
- Spec file updates:
  * Updated XOrg and Mesa BuildRequires: for openSUSE > 12.1.
  * Added libXt-devel in BuildRequires: for openSUSE > 12.1 in order to fix
    compilation.
* Fri Dec 30 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Include version in jars and javadoc.
* Fri Dec 30 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Added jpackage-utils in BuildRequires: and Requires:. Added java in
    Requires:.
  * Install the jar files in %%{_javadir}/java3d instead of %%{_javadir}.
* Tue Dec 27 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Added ant-nodeps in BuildRequires: for openSUSE < 12.1 in order to fix
    compilation.
* Tue Dec 27 2011 asterios.dramis@gmail.com
- Initial release (version 1.5.2).
